class InvalidObjectIdException(Exception):
    def __init__(self, oid: str):
        self.message = f"The given id {oid} does not represent a valid bson.ObjectId"

    def __str__(self) -> str:
        return self.message


class ResourceNotFoundException(Exception):
    def __init__(self, search_criteria: str):
        self.message = f"Resource with search_criteria {search_criteria} not found"

    def __str__(self) -> str:
        return self.message


class ResourceNotUpdatedException(Exception):
    def __init__(self, resource_id: str):
        self.message = f"Resource with id {resource_id} not updated"

    def __str__(self) -> str:
        return self.message


class ResourceExistsException(Exception):
    def __init__(self, resource_id: str):
        self.message = f"Resource with id {resource_id} exists"

    def __str__(self) -> str:
        return self.message




from pydantic import BaseModel, Field
from typing import Optional

from navalmartin_mir_db_utils.utils.transform_utils import stringify_dictionary


class IndexedItemDataViewBase(BaseModel):
    idx: Optional[str] = Field(title="idx",
                               description="The MongoDB index of the item",
                               alias="_id")

    created_at: Optional[str] = Field(
        title="created_at", description="Time and date the particular entry was created"
    )
    updated_at: Optional[str] = Field(
        title="updated_at", description="Time and date the particular entry was updated"
    )

    @staticmethod
    def build_from_mongodb_json(
            mdb_json: dict
    ) -> "IndexedItemDataViewBase":
        """Build the user data from the specified MongoDB document

        Parameters
        ----------
        mdb_json: The MongoDB document
        
        Returns
        -------

        """

        data = stringify_dictionary(data=mdb_json,
                                    names=["_id", "created_at", "updated_at"],
                                    )
        return IndexedItemDataViewBase(**data)




from .transform_utils import (stringify_dictionary, stringify_list)
from .exceptions import (ResourceNotFoundException, ResourceNotUpdatedException)
from .db_enums import (TaskStateTypeEnum, ErrorTypeEnum)